@@ -1,10 +1,10 @@
-quick_check_evds <- function(key = "..") {
-  url <- create_evds_url("subject", key = key)
-  gelen <- request_httr2_helper_evds(url, cache = F)
-  if (!is_response(gelen)) {
-    return(false)
-  }
-  T
+quick_check_evds <- function(key ) {
+  domain <- "https://evds2.tcmb.gov.tr/service/evds"
+
+  url <- glue::glue("{domain}/categories/type=json")
+  resp <- req_version_2_w_header(url, key = key)
+
+  return(is_response(resp))
 }
 mock_data_evds <- function() {
   dates <- seq(from = lubridate::ymd("2010-1-1"), to = lubridate::ymd("2025-1-1"), by = "month")
